<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt_BR">
<context>
    <name>AboutBox</name>
    <message>
        <location filename="../ui/aboutbox.ui" line="14"/>
        <source>About FMIT...</source>
        <translation>Sobre o FMIT...</translation>
    </message>
    <message>
        <location filename="../ui/aboutbox.ui" line="28"/>
        <source>About</source>
        <translation>Sobre</translation>
    </message>
    <message>
        <location filename="../ui/aboutbox.ui" line="88"/>
        <source>FMIT</source>
        <translation>FMIT</translation>
    </message>
    <message>
        <location filename="../ui/aboutbox.ui" line="98"/>
        <source>&lt;version&gt;</source>
        <translation>&lt;versão&gt;</translation>
    </message>
    <message>
        <location filename="../ui/aboutbox.ui" line="123"/>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Ubuntu&apos;; font-size:11pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;br /&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Ubuntu&apos;; font-size:11pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;br /&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../ui/aboutbox.ui" line="143"/>
        <source>Credits</source>
        <translation>Créditos</translation>
    </message>
    <message>
        <location filename="../ui/aboutbox.ui" line="158"/>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Ubuntu&apos;; font-size:11pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Most open-source softwares are infeasible without indirect contributions provided through libraries. Thus, big thanks to the following geeks:&lt;br /&gt;&lt;br /&gt;- dsboger for so many little and usefull changes, updates, packaging, etc.&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;- Florian Hars for the tunning scales&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;- Arnout Engelen for the JACK issues&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;- John Anderson for the microtonal module idea&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;- Scott Bahling for the scales in cents&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;- Jacob Shapiro for his help to make FMIT working under Windows/Cygwin.&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;br /&gt;- Translators: Omega9 (Russian), skarmoutsosv (Greek), Pindaro and dsboger (Portuguese and Brazilian Portuguese), Florian Maier (German).&lt;br /&gt;&lt;br /&gt;- &lt;a href=&quot;http://www.fftw.org/&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;FFTW3&lt;/span&gt;&lt;/a&gt;&apos; for the very Fast Fourier Transform.&lt;br /&gt;&lt;br /&gt;- &lt;a href=&quot;http://www.qt.io/&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;Qt&lt;/span&gt;&lt;/a&gt;&apos;s team for the GUI library.&lt;br /&gt;&lt;br /&gt;Any contribution of any sort is very welcome!&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Ubuntu&apos;; font-size:11pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;A maioria do software de código aberto seria impossível sem contribuições indiretas na forma de bibliotecas. Por isso, muito obrigado aos seguintes geeks:&lt;br /&gt;&lt;br /&gt;- dsboger por tantas pequenas e úteis modificações, atualizações, empacotamento, etc.&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;- Florian Hars pelas escalas de afinação&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;- Arnout Engelen pelas questões relacionadas a JACK&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;- John Anderson pela ideia do módulo microtonal&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;- Scott Bahling pelas escalas em cents&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;- Jacob Shapiro pela ajuda em fazer o FMIT funcionar no Windows/Cygwin.&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;br /&gt;- Tradutores: Omega9 (russo), skarmoutsosv (grego), Pindaro and dsboger (português de Portugal e do Brasil), Florian Maier (alemão).&lt;br /&gt;&lt;br /&gt;- &lt;a href=&quot;http://www.fftw.org/&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;Equipe FFTW3&lt;/span&gt;&lt;/a&gt; pela Transformada (muito) Rápida de Fourier.&lt;br /&gt;&lt;br /&gt;- &lt;a href=&quot;http://www.qt.io/&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;Equipe Qt&lt;/span&gt;&lt;/a&gt; pela biblioteca de interface gráfica.&lt;br /&gt;&lt;br /&gt;Qualquer tipo de contribuição é muito bem-vinda!&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Ubuntu&apos;; font-size:11pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Most open-source softwares are infeasible without indirect contributions provided through libraries. Thus, big thanks to the following geeks:&lt;br /&gt;&lt;br /&gt;- Florian Hars for the tunning scales; Arnout Engelen for the JACK issues; John Anderson for the microtonal module idea; Scott Bahling for the scales in cents; Jacob Shapiro for his help to make FMIT working under Windows/Cygwin.&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;br /&gt;- Translators: Omega9 (Russian), skarmoutsosv (Greek), Pindaro and dsboger (Portuguese and Brazilian Portuguese), Florian Maier (German).&lt;br /&gt;&lt;br /&gt;- &lt;a href=&quot;http://www.fftw.org/&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;FFTW3&lt;/span&gt;&lt;/a&gt;&apos; for the very Fast Fourier Transform.&lt;br /&gt;&lt;br /&gt;- &lt;a href=&quot;http://www.qt.io/&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;Qt&lt;/span&gt;&lt;/a&gt;&apos;s team for the GUI library.&lt;br /&gt;&lt;br /&gt;Any contribution of any sort is very welcome and will be rewarded by your name in this about box!&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="vanished">&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Ubuntu&apos;; font-size:11pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;A maioria dos softwares de código aberto não são factíveis sem contribuições indiretas na forma de bibliotecas. Portanto, muitíssimo obrigado aos seuintes geeks:&lt;br /&gt;&lt;br /&gt;- Florian Hars pelas escalas de afinação; Arnout Engelen pelos problemas com JACK; John Anderson pela ideia do módulo microtonal; Scott Bahling pelas escalas em cents; Jacob Shapiro pela ajuda para fazer o FMIT funcionar no Windows/Cygwin.&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;br /&gt;- Tradutores: Omega9 (russo), skarmoutsosv (grego), Pindaro e dsboger (português e português do Brasil), Florian Maier (alemão).&lt;br /&gt;&lt;br /&gt;- &lt;a href=&quot;http://www.fftw.org/&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;Equipe FFTW3&lt;/span&gt;&lt;/a&gt; pela rápida Transformada Rápida de Fourier.&lt;br /&gt;&lt;br /&gt;- &lt;a href=&quot;http://www.qt.io/&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;Equipe Qt&lt;/span&gt;&lt;/a&gt; pela biblioteca de interface gráfica.&lt;br /&gt;&lt;br /&gt;Quaisquer contribuições de todo tipo são muito bem vindas e serão recompensadas tendo o nome do autor colocado nesta caixa de sobre!&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
</context>
<context>
    <name>ConfigForm</name>
    <message>
        <location filename="../ui/ConfigForm.ui" line="14"/>
        <source>Configuration</source>
        <translation>Configuração</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="46"/>
        <source>General</source>
        <translation>Geral</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="60"/>
        <source>Start in full-screen</source>
        <translation>Iniciar em modo tela cheia</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="82"/>
        <source>Tuning scale</source>
        <translation>Escala de afinação</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="96"/>
        <source>Chromatic</source>
        <translation>Cromática</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="101"/>
        <source>Werckmeister III</source>
        <translation>Werckmeister III</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="106"/>
        <source>Kirnberger III</source>
        <translation>Kirnberger III</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="111"/>
        <source>Diatonic</source>
        <translation>Diatônica</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="116"/>
        <source>Meantone (1/4)</source>
        <translation>Mesotônica (1/4)</translation>
    </message>
    <message>
        <source>Tonality</source>
        <translation type="vanished">Tonalidade</translation>
    </message>
    <message>
        <source>C (Do)</source>
        <translation type="vanished">C (Dó)</translation>
    </message>
    <message>
        <source>Bb (Sib)</source>
        <translation type="vanished">Bb (Sib)</translation>
    </message>
    <message>
        <source>Eb (Mib)</source>
        <translation type="vanished">Eb (Mib)</translation>
    </message>
    <message>
        <source>Use anglo-saxon or latin note names:
anglo-saxon: C D E F G A B
latin: Do Re Mi Fa Sol La Si</source>
        <translation type="vanished">Usar nomes das notas anglo-saxônicos ou latinos:
anglo-saxônicos: C D E F G A B
latinos: Dó Ré Mi Fá Sol Lá Si</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="170"/>
        <source>Note names</source>
        <translation>Nomes das notas</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="188"/>
        <source>Anglo-Saxon</source>
        <translation>Anglo-saxônicos</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="193"/>
        <source>Latin</source>
        <translation>Latinos</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="266"/>
        <source>Capture System</source>
        <translation>Sistema de captura</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="307"/>
        <source>Auto-detect an available capture system at startup</source>
        <translation>Detectar sistema de captura automaticamente ao inciar</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="323"/>
        <source>Auto detect now</source>
        <translation>Detectar agora</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="332"/>
        <source>JACK</source>
        <translation>JACK</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="346"/>
        <source>Client name</source>
        <translation>Nome do cliente</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="368"/>
        <source>fmit</source>
        <translation>fmit</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="415"/>
        <location filename="../ui/ConfigForm.ui" line="418"/>
        <location filename="../ui/ConfigForm.ui" line="428"/>
        <location filename="../ui/ConfigForm.ui" line="431"/>
        <source>Sampling rate of the JACK server</source>
        <translation>Taxa de amostragem do servidor JACK</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="495"/>
        <location filename="../ui/ConfigForm.ui" line="611"/>
        <location filename="../ui/ConfigForm.ui" line="723"/>
        <location filename="../ui/ConfigForm.ui" line="835"/>
        <source>Sampling rate</source>
        <translation>Taxa de amostragem</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="443"/>
        <source>ALSA</source>
        <translation>ALSA</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="128"/>
        <source>Transposition</source>
        <translation>Transposição</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="160"/>
        <location filename="../ui/ConfigForm.ui" line="165"/>
        <location filename="../ui/ConfigForm.ui" line="177"/>
        <location filename="../ui/ConfigForm.ui" line="182"/>
        <source>Use localized note names. e.g.:
anglo-saxon: C D E F G A B
latin: Do Re Mi Fa Sol La Si</source>
        <translation>Usar nomes de notas locais. P.ex.:
anglo-saxônicos: C D E F G A B
latinos: Do Re Mi Fa Sol La Si</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="457"/>
        <location filename="../ui/ConfigForm.ui" line="573"/>
        <location filename="../ui/ConfigForm.ui" line="689"/>
        <location filename="../ui/ConfigForm.ui" line="801"/>
        <source>Device name</source>
        <translation>Nome do dispositivo</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="542"/>
        <location filename="../ui/ConfigForm.ui" line="658"/>
        <location filename="../ui/ConfigForm.ui" line="770"/>
        <location filename="../ui/ConfigForm.ui" line="882"/>
        <source>Do not use a too big sampling rate. 22050Hz should be largely enough in most cases.</source>
        <translation>Não use uma taxa de amostragem muito alta. 22050Hz deve ser suficiente na maioria dos casos.</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="559"/>
        <source>OSS</source>
        <translation>OSS</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="567"/>
        <location filename="../ui/ConfigForm.ui" line="570"/>
        <location filename="../ui/ConfigForm.ui" line="586"/>
        <location filename="../ui/ConfigForm.ui" line="589"/>
        <source>The name of the OSS device to connect to</source>
        <translation>Nome do dispositivo OSS para conectar</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="592"/>
        <source>/dev/dsp</source>
        <translation>/dev/dsp</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="675"/>
        <source>PortAudio</source>
        <translation>PortAudio</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="683"/>
        <location filename="../ui/ConfigForm.ui" line="686"/>
        <location filename="../ui/ConfigForm.ui" line="696"/>
        <location filename="../ui/ConfigForm.ui" line="699"/>
        <location filename="../ui/ConfigForm.ui" line="795"/>
        <location filename="../ui/ConfigForm.ui" line="798"/>
        <location filename="../ui/ConfigForm.ui" line="808"/>
        <location filename="../ui/ConfigForm.ui" line="811"/>
        <source>The name of the PortAudio device to connect to</source>
        <translation>Nome do dispositivo PortAudio para conectar</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="476"/>
        <location filename="../ui/ConfigForm.ui" line="703"/>
        <location filename="../ui/ConfigForm.ui" line="815"/>
        <source>default</source>
        <translation>default</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="52"/>
        <location filename="../ui/ConfigForm.ui" line="56"/>
        <source>Raise the window to the whole screen when the program is started
(You can also use the shortcut &apos;f&apos;).</source>
        <translation>Expandir a janela para ocupar a tela toda quando o programa é iniciado.
(Pode-se usar o atalho &apos;f&apos;).</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="67"/>
        <source>Auto-save configuration and layout on exit</source>
        <translation>Salvar configuração e layout automaticamente ao sair</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="76"/>
        <location filename="../ui/ConfigForm.ui" line="79"/>
        <location filename="../ui/ConfigForm.ui" line="89"/>
        <location filename="../ui/ConfigForm.ui" line="92"/>
        <source>The used tuning scale to determine note frequency values. Useful for tuning historic intruments.</source>
        <translation>Escala de afinação usada para determinar o valor das frequências das notas. Útil para afinar instrumentos históricos.</translation>
    </message>
    <message>
        <source>The used tonality.
Useful to convert note names to a corresponding instrument tonality (e.g. Eb for saxophone, Bb for trumpet).</source>
        <translation type="vanished">Tonalidade usada.
Útil para converter nomes de notas para a tonalidade correspondente ao instrumento (p.ex. Eb para saxofone, Bb para trompete).</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="198"/>
        <source>German</source>
        <translation>Alemães</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="203"/>
        <source>Hindustani</source>
        <translation>Hindustânis</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="208"/>
        <source>Byzantine</source>
        <translation>Bizantinos</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="274"/>
        <location filename="../ui/ConfigForm.ui" line="277"/>
        <source>The capture system (e.g. JACK, ALSA, OSS, PortAudio)</source>
        <translation>Sistema de captura (p.ex. JACK, ALSA, OSS, PortAudio)</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="280"/>
        <source>The capture system</source>
        <translation>O sistema de captura</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="287"/>
        <location filename="../ui/ConfigForm.ui" line="290"/>
        <source>Selected the capture system (e.g. JACK, ALSA, OSS, PortAudio)</source>
        <translation>Sistema de captura selecionado (p.ex. JACK, ALSA, OSS, PortAudio)</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="301"/>
        <location filename="../ui/ConfigForm.ui" line="304"/>
        <location filename="../ui/ConfigForm.ui" line="317"/>
        <location filename="../ui/ConfigForm.ui" line="320"/>
        <source>Auto detect a working capture system at FMIT startup.</source>
        <translation>Detectar um sistema de captura funcional automaticamente ao inciar FMIT.</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="340"/>
        <location filename="../ui/ConfigForm.ui" line="343"/>
        <location filename="../ui/ConfigForm.ui" line="362"/>
        <location filename="../ui/ConfigForm.ui" line="365"/>
        <source>The name of this FMIT instance in the JACK connections.</source>
        <translation>Nome dessa instância de FMIT nas conexões do JACK.</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="379"/>
        <location filename="../ui/ConfigForm.ui" line="382"/>
        <location filename="../ui/ConfigForm.ui" line="401"/>
        <location filename="../ui/ConfigForm.ui" line="404"/>
        <source>Automatically connect FMIT to the following source at startup (e.g. alsa_pcm:capture_1)</source>
        <translation>Conectar FMIT à fonte a seguir automaticamente ao iniciar (p.ex. alsa_pcm:capture_1)</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="385"/>
        <source>automaticaly connect to...</source>
        <translation>conectar automaticamente a...</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="421"/>
        <source>JACK sampling rate</source>
        <translation>Taxa de amostragem do JACK</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="451"/>
        <location filename="../ui/ConfigForm.ui" line="454"/>
        <location filename="../ui/ConfigForm.ui" line="470"/>
        <location filename="../ui/ConfigForm.ui" line="473"/>
        <source>The name of the ALSA device to use.</source>
        <translation>Nome do dispositivo ALSA para usar.</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="487"/>
        <location filename="../ui/ConfigForm.ui" line="491"/>
        <location filename="../ui/ConfigForm.ui" line="504"/>
        <location filename="../ui/ConfigForm.ui" line="508"/>
        <location filename="../ui/ConfigForm.ui" line="603"/>
        <location filename="../ui/ConfigForm.ui" line="607"/>
        <location filename="../ui/ConfigForm.ui" line="620"/>
        <location filename="../ui/ConfigForm.ui" line="624"/>
        <location filename="../ui/ConfigForm.ui" line="715"/>
        <location filename="../ui/ConfigForm.ui" line="719"/>
        <location filename="../ui/ConfigForm.ui" line="732"/>
        <location filename="../ui/ConfigForm.ui" line="736"/>
        <location filename="../ui/ConfigForm.ui" line="827"/>
        <location filename="../ui/ConfigForm.ui" line="831"/>
        <location filename="../ui/ConfigForm.ui" line="844"/>
        <location filename="../ui/ConfigForm.ui" line="848"/>
        <source>The chosen sampling rate.
Do not use a too big sampling rate. 22050Hz should be enough in most cases.</source>
        <translation>Taxa de amostragem escolhida.
Não use uma taxa de amostragem muito alta. 22050Hz deve ser suficiente na maioria dos casos.</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="525"/>
        <location filename="../ui/ConfigForm.ui" line="528"/>
        <location filename="../ui/ConfigForm.ui" line="641"/>
        <location filename="../ui/ConfigForm.ui" line="644"/>
        <location filename="../ui/ConfigForm.ui" line="753"/>
        <location filename="../ui/ConfigForm.ui" line="756"/>
        <location filename="../ui/ConfigForm.ui" line="865"/>
        <location filename="../ui/ConfigForm.ui" line="868"/>
        <source>Set the sampling rate to the maximum possible value.</source>
        <translation>Ajusta a taxa de amostragem para o maior valor possível.</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="531"/>
        <location filename="../ui/ConfigForm.ui" line="647"/>
        <location filename="../ui/ConfigForm.ui" line="759"/>
        <location filename="../ui/ConfigForm.ui" line="871"/>
        <source>set to max</source>
        <translation>escolher máximo</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="549"/>
        <location filename="../ui/ConfigForm.ui" line="665"/>
        <location filename="../ui/ConfigForm.ui" line="777"/>
        <location filename="../ui/ConfigForm.ui" line="889"/>
        <source>Mix channels if there are multiple (if unchecked, the first channel will be used)</source>
        <translation>Mixar canais se houver múltiplos deles (se desmarcado, o primeiro canal será usado)</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="787"/>
        <source>Qt</source>
        <translation>Qt</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="916"/>
        <source>Sound Analysis</source>
        <translation>Análise de som</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="924"/>
        <location filename="../ui/ConfigForm.ui" line="928"/>
        <location filename="../ui/ConfigForm.ui" line="939"/>
        <location filename="../ui/ConfigForm.ui" line="943"/>
        <source>Time between each sound analysis.
Can be increased to get less CPU usage (but less temporal precision).</source>
        <translation>Tempo entre cada análise de som.
Pode ser aumentado para diminuir o uso da CPU (porém com perda de precisão temporal).</translation>
    </message>
    <message>
        <source>Range of possible notes from the lowest to the highest around the A4 reference note.
Smaller the range, smaller the CPU usage.</source>
        <translation type="vanished">Intervalo de notas possíveis, do mais grave ao mais agudo, em torno da nota de referência A4.
Quanto menor o intervalo, menor o uso de CPU.</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="967"/>
        <source>Notes range</source>
        <translation>Intervalo de notas</translation>
    </message>
    <message>
        <source>Lowest semitone from the A4 reference note.
It can useful to put it higher than -35 to avoid disturbance from the sector alimentation (~50hz).</source>
        <translation type="vanished">Semitom mais grave da nota de referência A4.
Pode ser útil escolher um valor mais alto que -35 para evitar distúrbios da alimentação de setor (~50Hz).</translation>
    </message>
    <message>
        <source>Highest semitone from the A4 reference note.</source>
        <translation type="vanished">Semitom mais agudo da nota de referência A4.</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="1018"/>
        <location filename="../ui/ConfigForm.ui" line="1021"/>
        <source>Filter the sound below the lowest semitone and above the highest semitone to avoid artefacts and noises in all the following steps of the sound analysis.</source>
        <translation>Filtrar o som abaixo do semitom mais grave e acima do semitom mais agudo para evitar artefatos e ruídos em todos os passos seguintes da análise de som.</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="1024"/>
        <source>Notes range filtering</source>
        <translation>Filtragem do intervalo de notas</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="1070"/>
        <location filename="../ui/ConfigForm.ui" line="1074"/>
        <location filename="../ui/ConfigForm.ui" line="1100"/>
        <location filename="../ui/ConfigForm.ui" line="1104"/>
        <location filename="../ui/ConfigForm.ui" line="1278"/>
        <location filename="../ui/ConfigForm.ui" line="1282"/>
        <source>Ignore all sounds with volume below this threshold [dB]
(Shown as a red line in various views)</source>
        <translation>Ignorar todos os sons com volume abaixo desse limiar [dB]
(Exibido como uma linha vermelha em várias visualizações).</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="1131"/>
        <location filename="../ui/ConfigForm.ui" line="1136"/>
        <location filename="../ui/ConfigForm.ui" line="1163"/>
        <location filename="../ui/ConfigForm.ui" line="1168"/>
        <location filename="../ui/ConfigForm.ui" line="1188"/>
        <location filename="../ui/ConfigForm.ui" line="1193"/>
        <source>Ignore weak sub-harmonics.
This threshold is defined between two neighbors frequency components.
Prevents underestimation errors.</source>
        <translation>Ignorar subharmônicos fracos.
Esse limiar é definido entre dois componentes de frequência vizinhos.
Previne erros de subestimação.</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="1207"/>
        <location filename="../ui/ConfigForm.ui" line="1211"/>
        <location filename="../ui/ConfigForm.ui" line="1240"/>
        <location filename="../ui/ConfigForm.ui" line="1244"/>
        <location filename="../ui/ConfigForm.ui" line="1263"/>
        <location filename="../ui/ConfigForm.ui" line="1267"/>
        <source>Factor defining the window size (from the lowest possible period defined by the notes range).
The bigger this factor, the more stable the analysis. However, by increasing this factor, FMIT will need more CPU and will react slower to sound changes.</source>
        <translation>Fator que define o tamanho da janela (do período mais baixo possível definido no intervalo de notas).
Quanto maior o fator, mas estável é a análise. No entanto, ao aumentar o fator, FMIT percisará de mais CPU e reagirá mais lentamente a mudanças no som.</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="1472"/>
        <location filename="../ui/ConfigForm.ui" line="1476"/>
        <location filename="../ui/ConfigForm.ui" line="1487"/>
        <location filename="../ui/ConfigForm.ui" line="1491"/>
        <source>Quantize the analysis results: ignore frequency jumps, fill gaps, ignore short notes.
The smaller the value, the faster the tuner. However, by decreasing the value, the computed frequency will be more unstable.</source>
        <translation>Quantizar os resultados da análise: ignorar saltos de frequência, preencher lacunas, ignorar notas curtas.
Quanto menor o valor, mas rápido é o afinador. No entanto, ao diminuir o valor, a frequência calculada será mais instável.</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="1538"/>
        <location filename="../ui/ConfigForm.ui" line="1541"/>
        <source>Restore settings as if you just installed FMIT (requires to restart FMIT).</source>
        <translation>Restaurar configurações como um FMIT recém instalado (necessita reiniciar FMIT).</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="1567"/>
        <location filename="../ui/ConfigForm.ui" line="1570"/>
        <source>Use these settings and quit the configuration panel (it is required to click on the &quot;Save settings&quot; button to permanently keep these settings for each FMIT start)</source>
        <translation>Usar opções atuais e sair do painel de configuração (é necessário clicar no botão &quot;Salvar configurações&quot; para manter essas opções permanentemente)</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="1586"/>
        <location filename="../ui/ConfigForm.ui" line="1589"/>
        <source>Discard any changes and quit the configuration panel</source>
        <translation>Descartar modificações e sair do painel de configurações</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="932"/>
        <source>Refresh time</source>
        <translation>Tempo de atualização</translation>
    </message>
    <message>
        <source>Allows to add an offset to the reference A4</source>
        <translation type="vanished">Permite adicionar um deslocamento em relação à referência A4</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="238"/>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body&gt;
&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;To get more options, right-click every view to show up their properties!&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body&gt;
&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Para ver mais opções, clique com o botão direito em qualquer visualização para mostrar suas propriedades!&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="947"/>
        <location filename="../ui/ConfigForm.ui" line="1495"/>
        <source> ms</source>
        <translation> ms</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="1033"/>
        <source>Rectangular filter: bad precision, but very fast</source>
        <translation>Filtro retangular: precisão ruim, mas muito rápido</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="1046"/>
        <source>FIR filter: good precision, but more costly in CPU usage</source>
        <translation>Filtro FIR: precisão boa, porém maior consumo de CPU</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="1056"/>
        <location filename="../ui/ConfigForm.ui" line="1059"/>
        <source>Algorithm settings</source>
        <translation>Configurações do algoritmo</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="1062"/>
        <source>Algorithm</source>
        <translation>Algoritmo</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="1108"/>
        <location filename="../ui/ConfigForm.ui" line="1173"/>
        <source> dB</source>
        <translation> dB</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="1198"/>
        <source>Use sub-harmonic audibility threshold</source>
        <translation>Usar limiar de audibilidade de subharmônicos</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="1271"/>
        <source>Window size factor</source>
        <translation>Fator de tamanho de janela</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="1286"/>
        <source>Volume threshold</source>
        <translation>Limiar de volume</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="1296"/>
        <location filename="../ui/ConfigForm.ui" line="1299"/>
        <source>Frequency refinement settings</source>
        <translation>Configurações do refinamento de frequência</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="1302"/>
        <source>Frequency refinement</source>
        <translation>Refinamento de frequência</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="1311"/>
        <location filename="../ui/ConfigForm.ui" line="1314"/>
        <location filename="../ui/ConfigForm.ui" line="1396"/>
        <location filename="../ui/ConfigForm.ui" line="1399"/>
        <source>Use a refinement method in frequency domain: compute the mean of the quasi-harmonic related spectral peaks (the option allows to chose the number of harmonics to use).</source>
        <translation>Usar um método de refinamento no domínio da frequência: calcular a média dos picos espectrais quasi-harmônicos relacionados (a opção permite escolher o número de harmônicos usados).</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="1324"/>
        <location filename="../ui/ConfigForm.ui" line="1327"/>
        <location filename="../ui/ConfigForm.ui" line="1342"/>
        <location filename="../ui/ConfigForm.ui" line="1345"/>
        <location filename="../ui/ConfigForm.ui" line="1373"/>
        <location filename="../ui/ConfigForm.ui" line="1376"/>
        <source>Use a refinement method in time domain: compute the mean of various period lengths (the option allows to chose the number of periods to use).</source>
        <translation>Usar um método de refinamento no domínio do tempo: calcular a média de vários de períodos (a opção permite escolher o número de períodos usados).</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="1427"/>
        <location filename="../ui/ConfigForm.ui" line="1432"/>
        <source>Frequency domain fundamental refinement:
mean of the fundamental relative frequencies of the harmonics.
Choose the number of harmonics to use.</source>
        <translation>Refinamento fundamental no domínio da frequência
média das frequências fundamentais relativas dos harmônicos.
Escolhe o número de harmônicos usados.</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="1317"/>
        <source>Maximum number of harmonics</source>
        <translation>Número máximo de harmônicos</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="1330"/>
        <source>Maximum number of periods</source>
        <translation>Número máximo de períodos</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="1455"/>
        <location filename="../ui/ConfigForm.ui" line="1458"/>
        <source>Quantizer settings</source>
        <translation>Configurações do quantizador</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="1461"/>
        <source>Quantizer</source>
        <translation>Quantizador</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="1480"/>
        <source>Latency</source>
        <translation>Latência</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="1544"/>
        <source>Restore &amp;factory settings</source>
        <translation>Restaurar configurações de &amp;fábrica</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="1573"/>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="1592"/>
        <source>&amp;Cancel</source>
        <translation>&amp;Cancelar</translation>
    </message>
</context>
<context>
    <name>CustomInstrumentTunerForm</name>
    <message>
        <location filename="../src/CustomInstrumentTunerForm.cpp" line="1054"/>
        <location filename="../src/CustomInstrumentTunerForm.cpp" line="1067"/>
        <source>Restore Factory Settings</source>
        <translation>Restaurar configurações de fábrica</translation>
    </message>
    <message>
        <location filename="../src/CustomInstrumentTunerForm.cpp" line="1054"/>
        <source>This operation is NOT reversible.
Are you sure you want to lose all your current settings ?</source>
        <translation>Esta operação NÃO é reversível.
Tem certeza de que deseja perder todas as configurações atuais?</translation>
    </message>
    <message>
        <location filename="../src/CustomInstrumentTunerForm.cpp" line="1067"/>
        <source>You can now restart FMIT to get back factory settings</source>
        <translation>Reinicie FMIT agora para voltar às configurações de fábrica.</translation>
    </message>
    <message>
        <source>The used tonality.
Useful to convert note names to a corresponding instrument tonality (e.g. %1 for saxophone, %2 for trumpet).</source>
        <translation type="vanished">A tonalidade usada.
Útil para converter nomes de notas para a tonalidade do instrumento (p.ex. %1 para saxofone, %2 para trompete).</translation>
    </message>
    <message>
        <location filename="../src/CustomInstrumentTunerForm.cpp" line="1174"/>
        <source>Transposition in number of semitones relative to %1.
Useful to convert note names to a corresponding transposing instrument (e.g. %2 for saxophone, %3 for trumpet).</source>
        <translation>Transposição em número de semitons relativos a %1.
Útil para converter os nomes das notas conforme um instrumento transpositor (p.ex. %2 para saxofone, %3 para trompete).</translation>
    </message>
    <message>
        <location filename="../src/CustomInstrumentTunerForm.cpp" line="1187"/>
        <source>The base tunning frequency (the %1 frequency)</source>
        <translation>A frequência base de afinação (%1)</translation>
    </message>
    <message>
        <location filename="../src/CustomInstrumentTunerForm.cpp" line="1194"/>
        <source>Allows to add an offset to the reference %1</source>
        <translation>Permitir adicionar um deslocamento à referência %1</translation>
    </message>
    <message>
        <location filename="../src/CustomInstrumentTunerForm.cpp" line="1198"/>
        <source>Range of possible notes from the lowest to the highest around the %1 reference note.
Smaller the range, smaller the CPU usage.</source>
        <translation>Gama de notas possíveis do mais baixo ao mais alto em torno da nota de referência %1.
 Menor o alcance, menor o uso da CPU.</translation>
    </message>
    <message>
        <location filename="../src/CustomInstrumentTunerForm.cpp" line="1203"/>
        <source>Lowest semitone from the %1 reference note.
It can useful to put it higher than -35 to avoid disturbance from the sector alimentation (~50hz).</source>
        <translation>Menor semitom relativo à nota de referência %1.
Um valor maior que -35 pode ser útil para reduzir ruídos da fonte de alimentação (~50Hz).</translation>
    </message>
    <message>
        <location filename="../src/CustomInstrumentTunerForm.cpp" line="1210"/>
        <source>Highest semitone from the %1 reference note.</source>
        <translation>Maior semitom relativo à nota de referência %1.</translation>
    </message>
</context>
<context>
    <name>DialView</name>
    <message>
        <location filename="../src/modules/DialView.cpp" line="15"/>
        <source>Dial</source>
        <translation>Mostrador</translation>
    </message>
    <message>
        <location filename="../src/modules/DialView.cpp" line="22"/>
        <source>Show tolerance</source>
        <translation>Mostrar tolerância</translation>
    </message>
    <message>
        <location filename="../src/modules/DialView.cpp" line="28"/>
        <source>Show trace</source>
        <translation>Mostrar rastro</translation>
    </message>
    <message>
        <location filename="../src/modules/DialView.cpp" line="34"/>
        <source>Use cents</source>
        <translation>Usar cents</translation>
    </message>
    <message>
        <location filename="../src/modules/DialView.cpp" line="42"/>
        <source>Scale range</source>
        <translation>Intervalo de escala</translation>
    </message>
    <message>
        <location filename="../src/modules/DialView.cpp" line="50"/>
        <source>Scale range (in cents)</source>
        <translation>Intervalo de escala (em cents)</translation>
    </message>
</context>
<context>
    <name>GLErrorHistory</name>
    <message>
        <location filename="../src/modules/GLErrorHistory.cpp" line="75"/>
        <source>Error history</source>
        <translation>Histórico de erro</translation>
    </message>
    <message>
        <location filename="../src/modules/GLErrorHistory.cpp" line="82"/>
        <source>Keep previous notes</source>
        <translation>Manter notas anteriores</translation>
    </message>
    <message>
        <location filename="../src/modules/GLErrorHistory.cpp" line="88"/>
        <source>Use cents</source>
        <translation>Usar cents</translation>
    </message>
    <message>
        <location filename="../src/modules/GLErrorHistory.cpp" line="96"/>
        <source>Scale range</source>
        <translation>Intervalo de escala</translation>
    </message>
    <message>
        <location filename="../src/modules/GLErrorHistory.cpp" line="104"/>
        <source>Scale range (in cents)</source>
        <translation>Intervalo de escala (em cents)</translation>
    </message>
    <message>
        <location filename="../src/modules/GLErrorHistory.cpp" line="229"/>
        <source>Error</source>
        <translation>Erro</translation>
    </message>
</context>
<context>
    <name>GLFT</name>
    <message>
        <location filename="../src/modules/GLFT.cpp" line="52"/>
        <source>dB scale</source>
        <translation>Escala em dB</translation>
    </message>
    <message>
        <location filename="../src/modules/GLFT.cpp" line="61"/>
        <source>Size</source>
        <translation>Tamanho</translation>
    </message>
    <message>
        <location filename="../src/modules/GLFT.cpp" line="71"/>
        <source>window length</source>
        <translation>comprimento da janela</translation>
    </message>
    <message>
        <location filename="../src/modules/GLFT.cpp" line="83"/>
        <source>- Press left mouse button to move the view</source>
        <translation>- Pressione o botão esquerdo do mouse para mover a visualização</translation>
    </message>
    <message>
        <location filename="../src/modules/GLFT.cpp" line="86"/>
        <source>- Press SHIFT key and left mouse button to zoom in and out</source>
        <translation>- Pressione a tecla Shift e o botão esquerdo do mouse para aumentar ou diminuir o zoom</translation>
    </message>
    <message>
        <location filename="../src/modules/GLFT.cpp" line="89"/>
        <source>- Double-click to reset the view</source>
        <translation>- Clique duplo para reiniciar a visualização</translation>
    </message>
    <message>
        <location filename="../src/modules/GLFT.cpp" line="177"/>
        <source>Frequency %1 [Hz]</source>
        <translation>Frequência %1 [Hz]</translation>
    </message>
    <message>
        <location filename="../src/modules/GLFT.cpp" line="39"/>
        <location filename="../src/modules/GLFT.cpp" line="253"/>
        <source>Fourier Transform</source>
        <translation>Transformada de Fourier</translation>
    </message>
</context>
<context>
    <name>GLFreqStruct</name>
    <message>
        <location filename="../src/modules/GLFreqStruct.cpp" line="44"/>
        <location filename="../src/modules/GLFreqStruct.cpp" line="53"/>
        <source>Number of harmonics</source>
        <translation>Número de harmônicos</translation>
    </message>
    <message>
        <location filename="../src/modules/GLFreqStruct.cpp" line="182"/>
        <source>Harmonics&apos; amplitude</source>
        <translation>Amplitude dos harmônicos</translation>
    </message>
    <message>
        <location filename="../src/modules/GLFreqStruct.cpp" line="33"/>
        <source>Harmonics</source>
        <translation>Harmônicos</translation>
    </message>
</context>
<context>
    <name>GLGraph</name>
    <message>
        <location filename="../src/modules/GLGraph.cpp" line="43"/>
        <source>Show Wave Form</source>
        <translation>Mostrar forma de onda</translation>
    </message>
    <message>
        <location filename="../src/modules/GLGraph.cpp" line="49"/>
        <source>Auto scale</source>
        <translation>Escala automática</translation>
    </message>
    <message>
        <location filename="../src/modules/GLGraph.cpp" line="57"/>
        <location filename="../src/modules/GLGraph.cpp" line="64"/>
        <source>Scale factor</source>
        <translation>Fator de escala</translation>
    </message>
    <message>
        <location filename="../src/modules/GLGraph.cpp" line="78"/>
        <location filename="../src/modules/GLGraph.cpp" line="85"/>
        <source>Duration</source>
        <translation>Duração</translation>
    </message>
    <message>
        <location filename="../src/modules/GLGraph.cpp" line="99"/>
        <location filename="../src/modules/GLGraph.cpp" line="106"/>
        <source>Max height</source>
        <translation>Altura máxima</translation>
    </message>
    <message>
        <location filename="../src/modules/GLGraph.cpp" line="34"/>
        <location filename="../src/modules/GLGraph.cpp" line="267"/>
        <source>Captured Sound</source>
        <translation>Som capturado</translation>
    </message>
</context>
<context>
    <name>GLSample</name>
    <message>
        <location filename="../src/modules/GLSample.cpp" line="34"/>
        <source>Waveform</source>
        <translation>Forma de onda</translation>
    </message>
    <message>
        <location filename="../src/modules/GLSample.cpp" line="43"/>
        <source>Show fading</source>
        <translation>Mostrar fading</translation>
    </message>
    <message>
        <location filename="../src/modules/GLSample.cpp" line="50"/>
        <location filename="../src/modules/GLSample.cpp" line="58"/>
        <source>Number of fading</source>
        <translation>Número de fading</translation>
    </message>
    <message>
        <location filename="../src/modules/GLSample.cpp" line="127"/>
        <source>Waveform&apos;s period</source>
        <translation>Período da forma de onda</translation>
    </message>
</context>
<context>
    <name>GLStatistics</name>
    <message>
        <location filename="../src/modules/GLStatistics.cpp" line="200"/>
        <source>Reset statistics</source>
        <translation>Reiniciar estatísticas</translation>
    </message>
    <message>
        <location filename="../src/modules/GLStatistics.cpp" line="205"/>
        <source>Keep notes when hidden</source>
        <translation>Manter notas quando oculto</translation>
    </message>
    <message>
        <location filename="../src/modules/GLStatistics.cpp" line="213"/>
        <source>Keep n values</source>
        <translation>Manter n valores</translation>
    </message>
    <message>
        <location filename="../src/modules/GLStatistics.cpp" line="222"/>
        <source>Keep this number of values in the computation of the statistics</source>
        <translation>Manter esse número de valores no cálculo das estatísticas</translation>
    </message>
    <message>
        <location filename="../src/modules/GLStatistics.cpp" line="236"/>
        <source>Show standard deviation</source>
        <translation>Mostrar desvio padrão</translation>
    </message>
    <message>
        <location filename="../src/modules/GLStatistics.cpp" line="242"/>
        <source>Scale auto</source>
        <translation>Escala automática</translation>
    </message>
    <message>
        <location filename="../src/modules/GLStatistics.cpp" line="251"/>
        <source>Scale min</source>
        <translation>Mín. da escala</translation>
    </message>
    <message>
        <location filename="../src/modules/GLStatistics.cpp" line="260"/>
        <source>Scale min value (in semi-tones)</source>
        <translation>Valor mínimo da escala (em semitons)</translation>
    </message>
    <message>
        <location filename="../src/modules/GLStatistics.cpp" line="278"/>
        <source>Scale max</source>
        <translation>Máx. da escala</translation>
    </message>
    <message>
        <location filename="../src/modules/GLStatistics.cpp" line="287"/>
        <source>Scale max value (in semi-tones)</source>
        <translation>Valor máximo da escala (em semitons)</translation>
    </message>
    <message>
        <location filename="../src/modules/GLStatistics.cpp" line="303"/>
        <source>Show tolerance</source>
        <translation>Mostrar tolerância</translation>
    </message>
    <message>
        <location filename="../src/modules/GLStatistics.cpp" line="309"/>
        <source>Use cents</source>
        <translation>Usar cents</translation>
    </message>
    <message>
        <location filename="../src/modules/GLStatistics.cpp" line="317"/>
        <source>Scale range</source>
        <translation>Intervalo da escala</translation>
    </message>
    <message>
        <location filename="../src/modules/GLStatistics.cpp" line="325"/>
        <source>Scale range (in cents)</source>
        <translation>Intervalo de escala (em cents)</translation>
    </message>
    <message>
        <location filename="../src/modules/GLStatistics.cpp" line="192"/>
        <location filename="../src/modules/GLStatistics.cpp" line="437"/>
        <source>Statistics</source>
        <translation>Estatísticas</translation>
    </message>
</context>
<context>
    <name>GLVolumeHistory</name>
    <message>
        <location filename="../src/modules/GLVolumeHistory.cpp" line="49"/>
        <source>Volume history</source>
        <translation>Histórico de volume</translation>
    </message>
    <message>
        <location filename="../src/modules/GLVolumeHistory.cpp" line="59"/>
        <source>Keep previous notes</source>
        <translation>Manter notas anteriores</translation>
    </message>
    <message>
        <location filename="../src/modules/GLVolumeHistory.cpp" line="128"/>
        <source>Volume</source>
        <translation>Volume</translation>
    </message>
</context>
<context>
    <name>InstrumentTunerForm</name>
    <message>
        <location filename="../ui/InstrumentTunerForm.ui" line="14"/>
        <source>Free Music Instrument Tuner</source>
        <translation>Afinador de Instrumentos Musicais Livre</translation>
    </message>
    <message>
        <location filename="../ui/InstrumentTunerForm.ui" line="55"/>
        <source>K
e
e
p</source>
        <translation>K
e
e
p</translation>
    </message>
    <message>
        <location filename="../ui/InstrumentTunerForm.ui" line="61"/>
        <source>K</source>
        <translation>K</translation>
    </message>
    <message>
        <location filename="../ui/InstrumentTunerForm.ui" line="168"/>
        <source>Note Stability</source>
        <translation>Estabilidade da nota</translation>
    </message>
    <message>
        <location filename="../ui/InstrumentTunerForm.ui" line="192"/>
        <source>Tuning Frequency</source>
        <translation>Frequência de afinação</translation>
    </message>
    <message>
        <location filename="../ui/InstrumentTunerForm.ui" line="227"/>
        <source> Hz</source>
        <translation> Hz</translation>
    </message>
    <message>
        <location filename="../ui/InstrumentTunerForm.ui" line="256"/>
        <source>Offset</source>
        <translation>Distância</translation>
    </message>
    <message>
        <location filename="../ui/InstrumentTunerForm.ui" line="284"/>
        <source> cents</source>
        <translation> cents</translation>
    </message>
    <message>
        <location filename="../ui/InstrumentTunerForm.ui" line="348"/>
        <location filename="../ui/InstrumentTunerForm.ui" line="351"/>
        <source>The recognized note</source>
        <translation>Nota identificada</translation>
    </message>
    <message>
        <location filename="../ui/InstrumentTunerForm.ui" line="49"/>
        <location filename="../ui/InstrumentTunerForm.ui" line="52"/>
        <source>Keep the data in the error and volume views (shortcut &quot;k&quot;).</source>
        <translation>Manter os dados nas visualizações de erro e volume (atalho &quot;k&quot;).</translation>
    </message>
    <message>
        <location filename="../ui/InstrumentTunerForm.ui" line="111"/>
        <location filename="../ui/InstrumentTunerForm.ui" line="116"/>
        <source>Volume in dB.
Computed in the frequency domain, from the maximum bin.
The maximum is reached when the signal energy is maximal NOT when the sound is saturated in the time domain.</source>
        <translation>Volume em dB.
Calculado no domínio da frequência, a partir do bin máximo.
O máximo é atingido quando a energia do sinal está máxima, NÃO quando o som está saturado no domínio do tempo.</translation>
    </message>
    <message>
        <location filename="../ui/InstrumentTunerForm.ui" line="151"/>
        <location filename="../ui/InstrumentTunerForm.ui" line="158"/>
        <source>According to the following colors:
red       : the capture system is not working.
grey     : the capture system is OK, but there is not enough sound.
orange : the analysis conditions are bad (like saturation)
green   : a note is beeing analyzed and analysis conditions are OK.</source>
        <translation>Segundo as seguintes cores:
vermelho: o sistema de captura não está funcionando.
cinza: o sistema de captura está OK, porém não há som suficiente.
laranja: as condições de análise estão ruins (p.ex. saturação).
verde: a nota está sendo analisada e as condições de análise estão OK.</translation>
    </message>
    <message>
        <location filename="../ui/InstrumentTunerForm.ui" line="221"/>
        <location filename="../ui/InstrumentTunerForm.ui" line="224"/>
        <source>The base tunning frequency (the A4 frequency)</source>
        <translation>Frequência base de afinação (frequência de A4)</translation>
    </message>
    <message>
        <location filename="../ui/InstrumentTunerForm.ui" line="250"/>
        <location filename="../ui/InstrumentTunerForm.ui" line="253"/>
        <location filename="../ui/InstrumentTunerForm.ui" line="278"/>
        <location filename="../ui/InstrumentTunerForm.ui" line="281"/>
        <source>Offset in cents from the base tuning frequency</source>
        <translation>Distância em cents da frequência base de afinação</translation>
    </message>
    <message>
        <location filename="../ui/InstrumentTunerForm.ui" line="322"/>
        <location filename="../ui/InstrumentTunerForm.ui" line="325"/>
        <source>The frequency of the current note in Hertz.</source>
        <translation>Frequência da nota atual em Hertz.</translation>
    </message>
    <message>
        <location filename="../ui/InstrumentTunerForm.ui" line="376"/>
        <location filename="../ui/InstrumentTunerForm.ui" line="379"/>
        <source>The target frequency of the current note in Hertz.</source>
        <translation>Frequência alvo para a nota atual em Hertz.</translation>
    </message>
    <message>
        <location filename="../ui/InstrumentTunerForm.ui" line="408"/>
        <source>Views</source>
        <translation>Visualizações</translation>
    </message>
    <message>
        <location filename="../ui/InstrumentTunerForm.ui" line="422"/>
        <source>Settings</source>
        <translation>Configurações</translation>
    </message>
    <message>
        <location filename="../ui/InstrumentTunerForm.ui" line="444"/>
        <source>Pause</source>
        <translation>Pausar</translation>
    </message>
    <message>
        <location filename="../ui/InstrumentTunerForm.ui" line="447"/>
        <location filename="../ui/InstrumentTunerForm.ui" line="450"/>
        <source>Pause: the capture, the sound analysis and all views.</source>
        <translation>Pausar: captura, análise de som e todas as visualizações.</translation>
    </message>
    <message>
        <location filename="../ui/InstrumentTunerForm.ui" line="480"/>
        <location filename="../ui/InstrumentTunerForm.ui" line="483"/>
        <source>Save configuration panel settings, views settings and the window size.</source>
        <translation>Salvar opções do painel de configurações, visualizações e o tamanho da janela.</translation>
    </message>
    <message>
        <location filename="../ui/InstrumentTunerForm.ui" line="501"/>
        <location filename="../ui/InstrumentTunerForm.ui" line="504"/>
        <source>Invoke the about box.</source>
        <translation>Chamar o diálogo Sobre.</translation>
    </message>
    <message>
        <location filename="../ui/InstrumentTunerForm.ui" line="453"/>
        <source>Space</source>
        <translation>Espaço</translation>
    </message>
    <message>
        <location filename="../ui/InstrumentTunerForm.ui" line="465"/>
        <source>Configure</source>
        <translation>Configurações</translation>
    </message>
    <message>
        <location filename="../ui/InstrumentTunerForm.ui" line="477"/>
        <source>Save settings</source>
        <translation>Salvar configurações</translation>
    </message>
    <message>
        <location filename="../ui/InstrumentTunerForm.ui" line="486"/>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <location filename="../ui/InstrumentTunerForm.ui" line="498"/>
        <source>About</source>
        <translation>Sobre</translation>
    </message>
</context>
<context>
    <name>MicrotonalView</name>
    <message>
        <location filename="../src/modules/MicrotonalView.cpp" line="182"/>
        <source>Unkown filename: &apos;</source>
        <translation>Nome de arquivo desconhecido: &apos;</translation>
    </message>
    <message>
        <location filename="../src/modules/MicrotonalView.cpp" line="286"/>
        <source>Microtonal</source>
        <translation>Microtonal</translation>
    </message>
    <message>
        <location filename="../src/modules/MicrotonalView.cpp" line="287"/>
        <source>Used scale</source>
        <translation>Escala utilizada</translation>
    </message>
    <message>
        <location filename="../src/modules/MicrotonalView.cpp" line="304"/>
        <location filename="../src/modules/MicrotonalView.cpp" line="311"/>
        <source>Root&apos;s octave</source>
        <translation>Oitava da raiz</translation>
    </message>
    <message>
        <location filename="../src/modules/MicrotonalView.cpp" line="325"/>
        <source>Keep root to left side</source>
        <translation>Manter raiz na esquerda</translation>
    </message>
    <message>
        <location filename="../src/modules/MicrotonalView.cpp" line="330"/>
        <source>Load Scala file ...</source>
        <translation>Carregar arquivo Scala...</translation>
    </message>
    <message>
        <location filename="../src/modules/MicrotonalView.cpp" line="803"/>
        <location filename="../src/modules/MicrotonalView.cpp" line="810"/>
        <location filename="../src/modules/MicrotonalView.cpp" line="842"/>
        <location filename="../src/modules/MicrotonalView.cpp" line="846"/>
        <source>Open scale file</source>
        <translation>Abrir arquivo de escala</translation>
    </message>
    <message>
        <location filename="../src/modules/MicrotonalView.cpp" line="842"/>
        <source>Scale name already exist</source>
        <translation>Nome da escala já existe</translation>
    </message>
    <message>
        <location filename="../src/modules/MicrotonalView.cpp" line="846"/>
        <source>Invalid file content !</source>
        <translation>Conteúdo de arquivo inválido!</translation>
    </message>
    <message>
        <location filename="../src/modules/MicrotonalView.cpp" line="927"/>
        <source>&lt;b&gt;name:&lt;/b&gt; </source>
        <translation>&lt;b&gt;nome:&lt;/b&gt; </translation>
    </message>
    <message>
        <location filename="../src/modules/MicrotonalView.cpp" line="928"/>
        <source>&lt;b&gt;number of ratio:&lt;/b&gt; </source>
        <translation>&lt;b&gt;número de razão:&lt;/b&gt; </translation>
    </message>
    <message>
        <location filename="../src/modules/MicrotonalView.cpp" line="934"/>
        <source>Invalid Scala file: </source>
        <translation>Arquivo Scala inválido: </translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/CaptureThread.cpp" line="368"/>
        <source>default</source>
        <translation>default</translation>
    </message>
    <message>
        <location filename="../src/modules/View.cpp" line="86"/>
        <source>%1</source>
        <translation>%1</translation>
    </message>
</context>
</TS>
